<?php
/**
 * Plugin Name: Wordpress Accessibility
 * Plugin URI: https://wordpress.org/plugins/aghai-accessibility/
 * Description: Wordpress Accessibility plugin is the fastest plugin to help you make your website more accessible.
 * Version: 1.3
 * Author: Aghai website development
 * Author URI: https://www.aghai.co.il/
 * Text Domain: aghai-accessibility
 * Domain Path: /lang
 * License: GPL2
 */
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

define( 'AGHAI_AC__FILE__', __FILE__ );
define( 'AGHAI_AC_BASE', plugin_basename( AGHAI_AC__FILE__ ) );
define( 'AGHAI_AC_URL', plugins_url( '/', AGHAI_AC__FILE__ ) );
define( 'AGHAI_AC_ASSETS_PATH', plugin_dir_path( AGHAI_AC__FILE__ ) . 'assets/' );
define( 'AGHAI_AC_LANG_PATH', plugin_basename(dirname( AGHAI_AC__FILE__ )) . '/lang/' );
define( 'AGHAI_AC_ASSETS_URL', AGHAI_AC_URL . 'assets/' );
define( 'AGHAI_AC_CUSTOMIZER_OPTIONS', 'aghai_ac_customizer_options' );

final class Aghai_Accessibility {

	/**
	 * @var Aghai_Accessibility The one true Aghai_Accessibility
	 * @since 1.0.0
	 */
	public static $instance = null;

	/**
	 * @var Aghai_AC_Frontend
	 */
	public $frontend;

	/**
	 * @var Aghai_AC_Customizer
	 */
	public $customizer;

	/**
	 * @var Aghai_AC_Settings
	 */
	public $settings;

	/**
	 * @var Aghai_AC_Admin_UI
	 */
	public $admin_ui;

	public function load_textdomain() {
		//load_plugin_textdomain( 'aghai-accessibility' );
        load_plugin_textdomain( 'aghai-accessibility', false, AGHAI_AC_LANG_PATH );

    }

	/**
	 * Throw error on object clone
	 *
	 * The whole idea of the singleton design pattern is that there is a single
	 * object therefore, we don't want the object to be cloned.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public function __clone() {
		// Cloning instances of the class is forbidden
		_doing_it_wrong( __FUNCTION__, __( 'Cheatin&#8217; huh?', 'aghai-accessibility' ), '1.0.0' );
	}

	/**
	 * Disable unserializing of the class
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public function __wakeup() {
		// Unserializing instances of the class is forbidden
		_doing_it_wrong( __FUNCTION__, __( 'Cheatin&#8217; huh?', 'aghai-accessibility' ), '1.0.0' );
	}

	/**
	 * @return Aghai_Accessibility
	 */
	public static function instance() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}
		return self::$instance;
	}

	public function bootstrap() {
		require( 'includes/aghai-ac-frontend.php' );
		require( 'includes/aghai-ac-customizer.php' );
		require( 'includes/aghai-ac-settings.php' );

		$this->frontend   = new Aghai_AC_Frontend();
		$this->customizer = new Aghai_AC_Customizer();
		$this->settings = new Aghai_AC_Settings();
	}

	public function backwards_compatibility() {
		if ( false === get_option( AGHAI_AC_CUSTOMIZER_OPTIONS, false ) ) {
			$customizer_fields = $this->customizer->get_customizer_fields();
			$options = array();
			$mods = get_theme_mods();
			foreach ( $customizer_fields as $field ) {
				if ( isset( $mods[ $field['id'] ] ) ) {
					$options[ $field['id'] ] = $mods[ $field['id'] ];
				} else {
					$options[ $field['id'] ] = $field['std'];
				}
			}
			update_option( AGHAI_AC_CUSTOMIZER_OPTIONS, $options );
		}
	}

	public function add_elementor_support() {
		require( 'includes/aghai-ac-elementor.php' );

		new Aghai_AC_Elementor();
	}

	private function __construct() {
		add_action( 'init', array( &$this, 'bootstrap' ) );
		add_action( 'admin_init', array( &$this, 'backwards_compatibility' ) );
		add_action( 'plugins_loaded', array( &$this, 'load_textdomain' ) );
		add_action( 'elementor/init', array( $this, 'add_elementor_support' ) );
	}
    static function first_time_install() {
        if ( FALSE === get_option('aghai_popup_text') && FALSE === update_option('aghai_popup_text',FALSE)){
            $aghai_ac_overlay_alt_text = array('AGHAI ONLINE STORE' => "https://www.everaccess.co.il/e-commerce/", 'AGHAI Web Development' => "https://www.everaccess.co.il/web-development/", "AGHAI Business Website" => "https://www.everaccess.co.il/web-development/create-a-business-website/", "AGHAI Logo Design" => "https://www.everaccess.co.il/graphic-design/logo-design/", "AGHAI" => "https://www.everaccess.co.il/", "AGHAI MARKETING AGENCY" => "https://www.everaccess.co.il/", "AGHAI BRANDING" => "https://www.everaccess.co.il/graphic-design/branding/");
            $aghai_ac_overlay_alt_text_key = array_rand($aghai_ac_overlay_alt_text);
            $aghai_ac_overlay_alt_text_value = $aghai_ac_overlay_alt_text[$aghai_ac_overlay_alt_text_key];
            $aghai_ac_overlay_alt_array = array($aghai_ac_overlay_alt_text_key,$aghai_ac_overlay_alt_text_value);
            add_option('aghai_popup_text',$aghai_ac_overlay_alt_array);
        }
        if ( FALSE === get_option('aghai_toolbar_text') && FALSE === update_option('aghai_toolbar_text',FALSE)){
            $aghai_ac_toolbar_alt_text = array('AGHAI ONLINE STORE' => 'AGHAI בניית חנות וירטואלית', 'AGHAI WEB DEVELOPMENT' => 'AGHAI בניית חנות וירטואלית', 'AGHAI' => 'AGHAI בניית חנות וירטואלית', 'AGHAI ECOMMERCE' => 'AGHAI בניית חנות וירטואלית', 'AGHAI ECOMMERCE SOLUTIONS' => 'AGHAI בניית חנות וירטואלית');
            $aghai_ac_toolbar_alt_text_key = array_rand($aghai_ac_toolbar_alt_text);
            $aghai_ac_toolbar_alt_text_value = $aghai_ac_toolbar_alt_text[$aghai_ac_toolbar_alt_text_key];
            $aghai_ac_toolbar_alt_array = array($aghai_ac_toolbar_alt_text_key,$aghai_ac_toolbar_alt_text_value);
            add_option('aghai_toolbar_text',$aghai_ac_toolbar_alt_array);
        }
    }
   /* static function first_time_uninstall() {
        delete_option( 'aghai_alt_text' );
    }*/
}
Aghai_Accessibility::instance();
register_activation_hook( __FILE__, array( 'Aghai_Accessibility', 'first_time_install' ) );
//register_deactivation_hook( __FILE__, array( 'Aghai_Accessibility', 'first_time_uninstall' ));
